@@ -1,6 +1,6 @@
 package Log::Any::Adapter::JSON;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use strict;
 use warnings;
@@ -171,7 +171,7 @@ __END__
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =encoding utf8
 
@@ -308,7 +308,7 @@ Reserved key names that may not be used in the first hashref include:
 
   $log->debug('the message', { tracker => 42 }, { foo => 'bar'});
 
-Output is a B<single string> with JSON like:
+Output is a B<single line> with JSON like:
 
   {
     "category":"main",
@@ -321,9 +321,11 @@ Output is a B<single string> with JSON like:
     "tracker":42
   }
 
+Another example:
+
   $log->debug('the message', { tracker => 42 }, {foo => 'bar'}, [1..3]);
 
-Output is a B<single string> with JSON like:
+Output is a B<single line> with JSON like:
 
   {
     "category":"main",
@@ -342,22 +344,22 @@ Output is a B<single string> with JSON like:
 =head2 Additional messages
 
 Any scalars that are passed that are not consumed as the values of formatting
-tokens will be included in an C<additonal_messages> key.
+tokens will be included in an C<additional_messages> key.
 
   $log->debug('a simple message', 'foo', 'bar');
 
-Output is a B<single string> with JSON like:
+Output is a B<single line> with JSON like:
 
-{
-  "additional_messages":[
-    'foo',
-    'bar'
-  ],
-  "category":"main",
-  "level":"debug",
-  "message":"hello, world",
-  "time":"2021-03-03T17:23:25.73124"
-}
+  {
+    "additional_messages":[
+      'foo',
+      'bar'
+    ],
+    "category":"main",
+    "level":"debug",
+    "message":"hello, world",
+    "time":"2021-03-03T17:23:25.73124"
+  }
 
 =head1 SEE ALSO
 
